
# Type: subproperty_of


Ontology property which this slot is a subproperty of

URI: [meta:subproperty_of](https://w3id.org/biolink/biolinkml/meta/subproperty_of)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdfs:subPropertyOf |

